File References — Renku 0.15.2.dev42-g8ea0d1bb-dirty documentation

# File References

Manage names of Renku objects.

class `renku.core.models.refs.` `LinkReference`(name, *, client=None)

  Manage linked object names.

  Method generated by attrs for class LinkReference.

  `REFS` = 'refs'

    Define a name of the folder with references in the Renku folder.

  classmethod `check_ref_format`(name, no_slashes=False)

    Ensures that a reference name is well formed.

    It follows Git naming convention:

    - any path component of it begins with “.”, or

    - it has double dots “..”, or

    - it has ASCII control characters, or

    - it has “:”, “?”, “[“, “\”, “^”, “~”, SP, or TAB anywhere, or

    - it has “*” anywhere, or

    - it ends with a “/”, or

    - it ends with “.lock”, or

    - it contains a “@{” portion

  classmethod `create`(client, name, force=False)

    Create symlink to object in reference path.

  `delete`()

    Delete the reference at the given path.

  classmethod `iter_items`(client, common_path=None)

    Find all references in the repository.

  `name_validator`(attribute, value)

    Validate reference name.

  property `path`

    Return full reference path.

  property `reference`

    Return the path we point to relative to the client.

  `rename`(new_name, force=False)

    Rename self to a new name.

  `set_reference`(reference)

    Set ourselves to the given reference path.